@@ -228,7 +228,7 @@ class BatchLine(ModelSQL, ModelView):
     code = fields.Char('Code', readonly=True,
             help='Chronological sequence of batch lines by posting date')
     posting_text = fields.Char('Posting Text', states=_LINE_STATES,
-            depends=_LINE_DEPENDS, select=True)
+            depends=_LINE_DEPENDS)
     batch = fields.Many2One('account.batch', 'Batch', ondelete='CASCADE',
             domain=[('journal', '=', Eval('journal'))], states={
                 'readonly': Or(
@@ -300,7 +300,7 @@ class BatchLine(ModelSQL, ModelView):
         'to compensate for a same move with original amount.')
     move = fields.Many2One('account.move', 'Account Move', readonly=True,
             select=True)
-    reference = fields.Char('Reference', select=True,
+    reference = fields.Char('Reference',
             states=_LINE_STATES, depends=_LINE_DEPENDS,
             help='This field collects references to external documents, '
             'like voucher or receipt numbers.')
@@ -343,14 +343,22 @@ class BatchLine(ModelSQL, ModelView):
         depends=_LINE_DEPENDS + ['party', 'tax'])
     tax = fields.Many2One('account.tax', 'Tax',
         domain=[
-            ('parent', '=', None)
+            ('parent', '=', None),
+            ['OR',
+                ('start_date', If(Eval('date'), '<=', '!='), Eval('date')),
+                ('start_date', '=', None),
+                ],
+            ['OR',
+                ('end_date', If(Eval('date'), '>=', '!='), Eval('date')),
+                ('end_date', '=', None),
+                ],
             ],
         states={'readonly':
                 Or(Bool(Eval('invoice')),
                     _LINE_STATES['readonly'],
                 )
             },
-        depends=_LINE_DEPENDS + ['invoice'])
+        depends=_LINE_DEPENDS + ['invoice', 'date'])
 
     @classmethod
     def __setup__(cls):
@@ -412,7 +420,7 @@ class BatchLine(ModelSQL, ModelView):
                 values['journal'] = context.get('journal')
 
             if 'account' in fields:
-                values['account'] = journal.account
+                values['account'] = journal.account.id
 
             if 'side_account' in fields:
                 values['side_account'] = side
@@ -538,7 +546,7 @@ class BatchLine(ModelSQL, ModelView):
             else:
                 self.account = self.invoice.account.id
 
-    @fields.depends('account', 'contra_account')
+    @fields.depends('account', 'contra_account', 'party', 'posting_text')
     def on_change_contra_account(self):
         if self.account == self.contra_account:
             self.contra_account = None
@@ -546,14 +554,17 @@ class BatchLine(ModelSQL, ModelView):
             taxes = self.contra_account.taxes
             if taxes and len(taxes) == 1:
                 self.tax = taxes[0].id
+        if self.party and not self.posting_text:
+            self.posting_text = self.party.rec_name
 
     @fields.depends('party', 'journal', 'amount', 'invoice', 'contra_account',
-        'tax')
+        'tax', 'posting_text')
     def on_change_party(self):
         # Set the default accounts when there is no contra_account or tax set
-        if (self.party and self.journal and (
-                    not self.contra_account or not self.tax)):
-            if self.amount:
+        if self.party:
+            if (self.journal
+                    and (not self.contra_account or not self.tax)
+                    and self.amount):
                 type_ = self.journal.account_journal.type
                 if type_ == 'expense':
                     self.account = self.party.account_payable.id
@@ -564,14 +575,21 @@ class BatchLine(ModelSQL, ModelView):
                         self.contra_account = self.party.account_receivable.id
                     else:
                         self.contra_account = self.party.account_payable.id
+            if not self.posting_text:
+                self.posting_text = self.party.rec_name
+        else:
+            self.posting_text = None
+
         if self.invoice:
             if self.party != self.invoice.party:
                 self.invoice = None
                 self.reference = None
+                self.posting_text = None
                 self.contra_account = None
             elif not self.party:
                 self.invoice = None
                 self.reference = None
+                self.posting_text = None
             else:
                 self.contra_account = self.invoice.account.id
 
@@ -635,6 +653,7 @@ class BatchLine(ModelSQL, ModelView):
             self.party = self.invoice.party.id
             self.contra_account = self.invoice.account.id
             self.reference = reference
+            self.posting_text = self.invoice.rec_name
         else:
             self.reference = None
 
@@ -824,7 +843,7 @@ class BatchLine(ModelSQL, ModelView):
             for tax in taxes:
                 total_amount = base_amount = amount
                 if not self.tax.reverse_charge:
-                    base_amount = tax.reverse_compute(amount, taxes)
+                    base_amount = tax.reverse_compute(amount, [tax])
                 if tax.type == 'percentage':
                     tax_amount = base_amount * tax.rate
                 elif tax.type == 'fixed':
@@ -966,8 +985,15 @@ class BatchLine(ModelSQL, ModelView):
             )
 
     def _get_taxes(self, tax):
+        pool = Pool()
+        Date = pool.get('ir.date')
+
+        context = Transaction().context
+        date = self.date or context.get('date') or Date.today()
         res = []
-        if tax.type != 'none':
+        if (tax.type != 'none'
+                and ((not tax.start_date or tax.start_date <= date)
+                and (not tax.end_date or tax.end_date >= date))):
             res.append(tax)
         if tax.childs:
             for child in tax.childs:
